* mln/registration/all.hh: New.
* mln/registration/icp.hh: Fix reference.
---
milena/ChangeLog | 8 ++++++++
milena/mln/{opt => registration}/all.hh | 22 ++++++++++------------
milena/mln/registration/icp.hh | 9 +++------
3 files changed, 21 insertions(+), 18 deletions(-)
copy milena/mln/{opt => registration}/all.hh (74%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 4bf766a..6a3fb73 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,13 @@
2013-03-21 Guillaume Lazzara <z(a)lrde.epita.fr>
+ Fix documentation in registration namespace.
+
+ * mln/registration/all.hh: New.
+
+ * mln/registration/icp.hh: Fix reference.
+
+2013-03-21 Guillaume Lazzara <z(a)lrde.epita.fr>
+
Fix invalid example output in the documentation.
* doc/examples/split/tuto3_first_routine-1.cc.raw,
diff --git a/milena/mln/registration/icp.hh b/milena/mln/registration/icp.hh
index 72b3d84..7c82202 100644
--- a/milena/mln/registration/icp.hh
+++ b/milena/mln/registration/icp.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2008, 2009, 2010, 2011 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2008, 2009, 2010, 2011, 2013 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -107,10 +107,7 @@ namespace mln
*
* \pre \p P_ and \p X must not be empty.
*
- * \cite besl.92.pami
- *
- * Reference article: "A Method for Registration of 3-D Shapes", Paul J.
- * Besl and Neil D. McKay, IEEE, 2, February 1992.
+ * This implementation is based on \cite besl1992pami.
*
*/
template <typename P, typename F>
diff --git a/milena/mln/opt/all.hh b/milena/mln/registration/all.hh
similarity index 74%
copy from milena/mln/opt/all.hh
copy to milena/mln/registration/all.hh
index 204b0c9..11b029c 100644
--- a/milena/mln/opt/all.hh
+++ b/milena/mln/registration/all.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2013 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,29 +23,27 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_OPT_ALL_HH
-# define MLN_OPT_ALL_HH
+#ifndef MLN_REGISTRATION_ALL_HH
+# define MLN_REGISTRATION_ALL_HH
/// \file
///
/// File that includes the most useful optional routines.
namespace mln
{
- /// Namespace of optional routines.
- namespace opt
+ /// Namespace of registrationional routines.
+ namespace registration
{
/// Implementation namespace of opt namespace.
namespace impl {}
- } // end of namespace mln::opt
+ } // end of namespace mln::registration
} // end of name
-# include <mln/opt/at.hh>
-# include <mln/opt/element.hh>
-# include <mln/opt/value.hh>
+# include <mln/registration/icp.hh>
-#endif // ! MLN_OPT_ALL_HH
+#endif // ! MLN_REGISTRATION_ALL_HH
@@ -23,29 +23,27 @@
/// \file
///
-/// File that includes the most useful optional routines.
+/// File that includes the most useful registration routines.
namespace mln
{
@@ -23,29 +23,27 @@
{
- /// Implementation namespace of opt namespace.
+ /// Implementation namespace of registration namespace.
namespace impl {}
--
1.7.2.5